import { JSXInternal } from "node_modules/preact/src/jsx";
import { LocationInfo } from "../../../domains";

interface ComponentProps {
  onCardClick: (id: number) => void,
  data: LocationInfo,
  containerClass?: string,
  containerStyle?: JSXInternal.CSSProperties
}

const LocationCard = (props: ComponentProps) => (
  <div className={props.containerClass} style={props.containerStyle}>
    <a onClick={() => props.onCardClick(props.data.id)}>
      <div className={'border-secondary recently-img-container'}>
        <img alt={props.data.name} src={props.data.thumbnail ? props.data.thumbnail : ''} loading="lazy" style={{ width: '100%', height: '100%' }} />
      </div>
    </a>
    <div className={"border-primary pb-2 location-container text-sm mb-2 mt-2"}>
      <p className={'location-title'}>{props.data.name}</p>
      <p className={'text-xs mt-1'}>{props.data.regency_name}, {props.data.province_name}</p>
    </div>
    {props.data.critic_count !== 0 &&
      <div className={"flex flex-row items-center mb-3"}>
        <div className={'mr-3 users-score-bar'}>
          <p className={'text-sm text-center'}>{props.data.critic_score}</p>
          <div style={{ height: 4, width: 30, backgroundColor: "#72767d" }}>
            <div style={{ height: 4, width: `${props.data.critic_score}%`, backgroundColor: 'green' }} />
          </div>
        </div>
        <p className={"users-score"}>critic score ({props.data.critic_count})</p>
      </div>
    }
    {props.data.user_score !== 0 &&
      <div className={"flex flex-row items-center"}>
        <div className={'mr-3 users-score-bar'}>
          <p className={'text-sm text-center'}>{props.data.user_score}</p>
          <div style={{ height: 4, width: 30, backgroundColor: "#72767d" }}>
            <div style={{ height: 4, width: ` ${props.data.user_score}%`, backgroundColor: 'green' }} />
          </div>
        </div>
        <p className={'users-score'}>user score ({props.data.user_count})</p>
      </div>
    }
  </div>
)

export default LocationCard;